@@ -86,20 +86,29 @@ class CreateSnapshotTaskRequest(AbstractModel):
         r"""
         :param Whiteboard: 白板相关参数
         :type Whiteboard: :class:`tencentcloud.tiw.v20190919.models.SnapshotWhiteboard`
-        :param SdkAppId: 白板房间SdkAppId
+        :param SdkAppId: 白板房间 `SdkAppId`
         :type SdkAppId: int
         :param RoomId: 白板房间号
         :type RoomId: int
         :param CallbackURL: 白板板书生成结果通知回调地址
         :type CallbackURL: str
-        :param COS: 白板板书文件COS存储参数， 不填默认存储在公共存储桶，公共存储桶的数据仅保存3天
+        :param COS: 白板板书文件 `COS` 存储参数， 不填默认存储在公共存储桶，公共存储桶的数据仅保存3天
         :type COS: :class:`tencentcloud.tiw.v20190919.models.SnapshotCOS`
+        :param SnapshotMode: 白板板书生成模式，默认为 `AllMarks`。取值说明如下：
+
+`AllMarks` - 全量模式，即对于客户端每一次调用 `addSnapshotMark` 接口打上的白板板书生成标志全部都会生成对应的白板板书图片。
+
+`LatestMarksOnly` - 单页去重模式，即对于客户端在同一页白板上多次调用 `addSnapshotMark` 打上的白板板书生成标志仅保留最新一次标志来生成对应白板页的白板板书图片。
+
+（**注意：`LatestMarksOnly` 模式只有客户端使用v2.6.8及以上版本的白板SDK调用 `addSnapshotMark` 时才生效，否则即使在调用本API是指定了 `LatestMarksOnly` 模式，服务后台会使用默认的 `AllMarks` 模式生成白板板书**）
+        :type SnapshotMode: str
         """
         self.Whiteboard = None
         self.SdkAppId = None
         self.RoomId = None
         self.CallbackURL = None
         self.COS = None
+        self.SnapshotMode = None
 
 
     def _deserialize(self, params):
@@ -112,6 +121,7 @@ class CreateSnapshotTaskRequest(AbstractModel):
         if params.get("COS") is not None:
             self.COS = SnapshotCOS()
             self.COS._deserialize(params.get("COS"))
+        self.SnapshotMode = params.get("SnapshotMode")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -2080,7 +2090,9 @@ class StartWhiteboardPushRequest(AbstractModel):
         r"""
         :param SdkAppId: 客户的SdkAppId
         :type SdkAppId: int
-        :param RoomId: 需要推流白板的房间号，取值范围: (1, 4294967295)
+        :param RoomId: 需要推流的白板房间号，取值范围: (1, 4294967295)。
+
+在没有指定TRTCRoomId和TRTCRoomIdStr的情况下，默认会以RoomId作为白板流进行推流的TRTC房间号。
         :type RoomId: int
         :param PushUserId: 用于白板推流服务进房进行推流的用户ID，最大长度不能大于60个字节，该ID必须是一个单独的未在SDK中使用的ID，白板推流服务使用这个用户ID进入房间进行白板音视频推流，若该ID和SDK中使用的ID重复，会导致SDK和白板推流服务互踢，影响正常推流。
         :type PushUserId: str
@@ -2146,6 +2158,16 @@ SdkAppID = 12345678，RoomID = 12345，PushUserID = push_user_1
         :type UserDefinedStreamId: str
         :param ExtraData: 内部参数，不需要关注此参数
         :type ExtraData: str
+        :param TRTCRoomId: TRTC数字类型房间号，取值范围: (1, 4294967295)。
+
+在同时指定了RoomId与TRTCRoomId的情况下，优先使用TRTCRoomId作为白板流进行推流的TRTC房间号。
+
+当指定了TRTCRoomIdStr的情况下，此字段将被忽略。
+        :type TRTCRoomId: int
+        :param TRTCRoomIdStr: TRTC字符串类型房间号。
+
+在指定了TRTCRoomIdStr的情况下，会优先使用TRTCRoomIdStr作为白板流进行推流的TRTC房间号。
+        :type TRTCRoomIdStr: str
         """
         self.SdkAppId = None
         self.RoomId = None
@@ -2163,6 +2185,8 @@ SdkAppID = 12345678，RoomID = 12345，PushUserID = push_user_1
         self.AutoPublish = None
         self.UserDefinedStreamId = None
         self.ExtraData = None
+        self.TRTCRoomId = None
+        self.TRTCRoomIdStr = None
 
 
     def _deserialize(self, params):
@@ -2186,6 +2210,8 @@ SdkAppID = 12345678，RoomID = 12345，PushUserID = push_user_1
         self.AutoPublish = params.get("AutoPublish")
         self.UserDefinedStreamId = params.get("UserDefinedStreamId")
         self.ExtraData = params.get("ExtraData")
+        self.TRTCRoomId = params.get("TRTCRoomId")
+        self.TRTCRoomIdStr = params.get("TRTCRoomIdStr")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -2561,9 +2587,9 @@ class Whiteboard(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Width: 实时录制结果里白板视频宽，默认为1280
+        :param Width: 实时录制结果里白板视频宽，取值必须大于等于2，默认为1280
         :type Width: int
-        :param Height: 实时录制结果里白板视频高，默认为960
+        :param Height: 实时录制结果里白板视频高，取值必须大于等于2，默认为960
         :type Height: int
         :param InitParam: 白板初始化参数，透传到白板 SDK
         :type InitParam: str
